==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/webmail/client/inc/obj_datagrid2_ext.js <==
_me = obj_datagrid2_ext.prototype;
function obj_datagrid2_ext(){};

//////////// Drag & Drop ////////////////////

_me.__initdrag = function(id,x,y){

	//Check if ID is already in selection, if not make new one
	if (inArray(this.__value,id)<0)
		this._value([id]);

	//prepare data
	var f = this._getFolder(), sType = dataSet.get('folders',[f.aid,f.fid,'TYPE']),
		v, sBody = '<table class="tbl_datagrid_'+sType+'">', data, out = [];

	for(var i in this.__valueData){

		if (!(data = this.__valueData[i]))
			continue;
		/*
		if (!(data = this._aData[this.__value[i]]))
			continue;
		*/
		out.push(typeof data == 'object' && data.arg?data.arg:{id:id});

		//prepare body
		switch(sType){
		case 'R':
		    return false;
		case 'Q':
		case 'M':
			sBody += '<tr><th>'+ (data.data.SUBJECT?data.data.SUBJECT[0]:'') +'</th><td>'+ (data.data.DATE?data.data.DATE[0]:'') +'</td><td>'+ (data.data.SIZE?data.data.SIZE[0]:'') +'</td></tr>';
			break;
        case 'J':
		case 'E':
			sBody += '<tr><th>'+ (data.data.EVNTITLE?data.data.EVNTITLE[0]:'') +'</th><td>'+ (data.data.EVENT_STARTDATE?data.data.EVENT_STARTDATE[0]:'') +'</td><td>-</td><td>'+ (data.data.EVENT_ENDDATE?data.data.EVENT_ENDDATE[0]:'') +'</td></tr>';
			break;
		case 'N':
			sBody += '<tr><th>'+ (data.data.EVNTITLE?data.data.EVNTITLE[0]:'') +'</th>';
			break;
		case 'T':
			sBody += '<tr><th>'+ (data.data.EVNTITLE?data.data.EVNTITLE[0]:'') +'</th><td>'+ (data.data.TASK_ENDDATE?data.data.TASK_ENDDATE[0]:'') +'</td></tr>';
			break;
		case 'C':
			sBody += '<tr><th>'+ (data.data.ITMCLASSIFYAS?(typeof data.data.ITMCLASSIFYAS == 'object'?data.data.ITMCLASSIFYAS[0]:data.data.ITMCLASSIFYAS):'') +'</th><td>'+ data.data.CONTACT_EMAIL +'</td></tr>';
			break;
		case 'F':
			sBody += '<tr><th>'+ data.data.EVNFILENAME +'</th><td>'+ (data.data.EVNFILESIZE?data.data.EVNFILESIZE[0]:'') +'</td></tr>';
			break;
		}
	}
	sBody += '</table>';

	//create Drag box
	if (out.length>0)
		gui.frm_main.dnd.create_drag(sBody, {type:this.__dragtype,value:out}, x, y);
};

//////////// EVENTs ////////////////////

_me._ondblclick = function(e,elm,arg){
	if (!elm){
		//var arg = this._getFolder();
		if (arg && arg['aid'] && arg['fid']){
			switch(dataSet.get('folders',[arg['aid'],arg['fid'],'TYPE'])){
				case 'C':
				case 'L':
				case 'E':
				case 'T':
				case 'J':
				case 'F':
				case 'N':
                    if (WMFolders.getAccess(arg,'write'))
						Item.createInFolder(arg['aid'],arg['fid']);
				break;
				case 'M':
					NewMessage.compose();
			}
		}
		return;
	}

	var sType = dataSet.get('folders',[arg['aid'],arg['fid'],'TYPE']);
	if (sType == 'C' && dataSet.get('items',[arg['aid'],arg['fid'],arg['iid'],'ITMCLASS']) == 'L')
		sType = 'L';

	if (sType == 'M') {
		var others = new gw_others;
		var aDraftFolder = Path.split(others.get('DEFAULT_FOLDERS','storage')['VALUES']['drafts']);

		if (aDraftFolder[0] != arg['aid'] || aDraftFolder[1] != arg['fid'])
			OldMessage.openwindow([arg['aid'], arg['fid'], arg['iid']]);
		else
			OldMessage.edit([arg['aid'], arg['fid'], arg['iid']]);
	}
	else
	if (sType == 'F') {
		if (!Item.downloadFile([arg['aid'], arg['fid'], arg['iid']]))
			gui._create('gw',Mapping.getFormNameByGWType(sType),'','',arg['aid'],arg['fid'],arg['iid']);
	}
	else
		gui._create('gw',Mapping.getFormNameByGWType(sType),'','',arg['aid'],arg['fid'],arg['iid']);
};

_me._oncontext = function(e,elm,arg,sLineId,sColumn){
	var bOut = false;

	//Klikly jsme na msto bez poloek?
	if (!arg || !arg['iid']){
		aItems = dataSet.get('items');

		for(var sAccId in aItems)
			for(var sFolId in aItems[sAccId])

		var arg = {'aid':sAccId,'fid':sFolId};
		bOut = true;
	}

	var sType = dataSet.get('folders',[arg['aid'],arg['fid'],'TYPE']);

	if (!bOut){
		if (sType == 'C' && dataSet.get('items',[arg['aid'],arg['fid'],arg['iid'],'ITMCLASS']) == 'L')
			sType = 'L';

		var aSelected = this._value();
		var bDisableOpen;

		if (inArray(aSelected,arg['iid']) >= 0 && aSelected.length > 1)
			bDisableOpen = true;
		else
			bDisableOpen = false;

		if (inArray(aSelected,arg['iid']) < 0)
			aSelected = [arg['iid']];
	}

	gui._create("cmenu","obj_context_item");

	if (bOut)
		gui.cmenu._fillGeneralMenu(sType,arg);
	else
		gui.cmenu._fillMenu(sType,arg,aSelected,bDisableOpen,false,sColumn);

	gui.cmenu._place(e.clientX,e.clientY);
};

_me._onclick = function(e,elm,arg,line,column,aClickType)
{
	if (inArray(aClickType,'SHIFT') > -1 || inArray(aClickType,'CTRL') > -1)
		return;

	var sType = dataSet.get('folders',[arg['aid'],arg['fid'],'TYPE']);

	switch (sType) {
		case 'Q':
		case 'M':
			if (column == 'COLOR') {
				var id = [arg['aid'],arg['fid'],arg['iid']];
				var sColor = OldMessage.getColor(id);

				if (sColor && (sColor == Item.COLORS.COMPLETE || sColor == Item.COLORS.CLEAR)) {
					storage.library('gw_others');
					var sDefaultColor = GWOthers.getItem('MAIL_SETTINGS_GENERAL','default_flag');

					OldMessage.setColor(id, sDefaultColor);
				} else {
					OldMessage.setColor(id, Item.COLORS.COMPLETE);
				}
			}
			else {
				dataSet.add('active_mails',[arg['aid'],arg['fid']],arg['iid']);
				OldMessage.open([arg['aid'], arg['fid'], arg['iid']]);
			}
			break;
		case 'R':
			dataSet.add('active_mails',[arg['aid'],arg['fid']],arg['iid']);
			OldMessage.open([arg['aid'], arg['fid'], arg['iid']]);

			break;

		case 'T':
			if (column == 'EVNSTATUS') {
				var sCurrentStatus = dataSet.get('items',[arg['aid'],arg['fid'],arg['iid']])['EVNSTATUS'];

				var sStatus = (sCurrentStatus != 'D') ? 'D' : 'N';

				// TODO rollback on error
				dataSet.add('items', [arg['aid'], arg['fid'], arg['iid'], 'EVNSTATUS'], sStatus);
				WMItems.add([arg['aid'], arg['fid'], arg['iid']], {'values': {'EVNSTATUS': sStatus}}, 'items');
				break;
			}

		case 'C':
		case 'E':
		case 'J':
		case 'N':
		case 'F':
			//Execute Edit dialog on Enter
			if (e.type == 'keydown' && e.keyCode == 13)
                gui._create('gw',Mapping.getFormNameByGWType(sType),'','',arg['aid'],arg['fid'],arg['iid']);
	}
};

_me._onkeydown = function(e){
	// nacte vybrane radky
	var value = this._value();
	if (count(value)<1) return;

	//ziska sFolId a sAccId
    var aFolder = this._getFolder(),
    	sAccId = aFolder.aid,
		sFolId = aFolder.fid,
		sType = dataSet.get('folders',[sAccId,sFolId,'TYPE']);

	//numbers as Flags
	if ((e.keyCode>95 && e.keyCode<106) || (e.keyCode==107 || e.keyCode==109)){
		var color;
		if (e.keyCode==107)
			color = 'COMPLETE';
		else
		if (e.keyCode==109)
			color = 'CLEAR';
		else{
			if (sType == 'M' || sType == 'R')
				var colors = ['RED','BLUE','GREEN','ORANGE','PURPLE','YELLOW'];
			else
			if (sType == 'N')
				var colors = ['BLUE','GREEN','RED','','GREY','YELLOW'];
			else
				var colors = ['RED','BLUE','GREEN','GREY','ORANGE','CYAN','BROWN','PURPLE','LIGHT_BLUE','YELLOW'];

			if(!(color = colors[e.keyCode-96])) return;
		}

		for(var i in value)
			if (sType == 'M' || sType == 'R')
				OldMessage.setColor([sAccId,sFolId,value[i]], Item.COLORS[color]);
			else
			if (WMFolders.getAccess({aid:sAccId,fid:sFolId},'modify'))
				Item.setColor([sAccId,sFolId,value[i]], Item.COLORS[color]);
	}
	else
	switch(e.keyCode){
	case 82:
		//r - Reply or Reply All
	    if (sType=='M')
			OldMessage.reply([sAccId,sFolId,value[0]],e.shiftKey);
		break;
	case 70:
		//f - Forward or FW as attachment
	    if (sType=='M')
			OldMessage.forward([sAccId,sFolId,value[0]],e.shiftKey);
		break;
	case 78: //n - New
	    if (sType=='M')
	        NewMessage.compose();
	    break;
	case 67: //c - Copy
		Item.copy([sAccId,sFolId,value]);
	    break;
	case 77: //m - Move
 		if (sType!='M' && !WMFolders.getAccess({aid:sAccId,fid:sFolId},'remove')) break;
		Item.move([sAccId,sFolId,value]);
	    break;
	case 69: //e - Read
	    if (sType=='M' || sType=='R')
			for(var i in value)
				OldMessage.markAsRead([sAccId,sFolId,value]);
		break;
	case 85: //u - Unread
	    if (sType=='M' || sType=='R')
			for(var i in value)
				OldMessage.markAsUnread([sAccId,sFolId,value]);
	    break;
	case 46: //delete

		if (sType!='Q' && sType!='QL' && !WMFolders.getAccess({aid:sAccId,fid:sFolId},'remove')) break;

		var pos = 0, v = clone(value), act = v.pop();
		var tmp = [],b;

		for(var i in this._aData){
			b = false;
			for(j in v){
				if (v[j] == i){
				    b = true
				    break;
				}
			}

			if (!b){
				if (act == i)
				    pos = tmp.length;

				tmp.push(i);
			}
		}

		tmp.splice(pos,1);

		var iNext;
		if (typeof tmp[pos] == 'undefined'){
			if (pos>0)
                iNext = tmp[--pos];
				//this._value([tmp[--pos]]);
		    	//this.__value = [tmp[--pos]];
		    else
		    if (typeof tmp[pos+1] == 'undefined')
                iNext = tmp[pos];
				//this._value([tmp[pos]]);
		    	//this.__value = [tmp[pos]];
		    else
                iNext = tmp[++pos];
				//this._value([tmp[++pos]]);
		    	//this.__value = [tmp[++pos]];
		}
		else
            iNext = tmp[pos];
			//this._value([tmp[pos]]);
			//this.__value = [tmp[pos]];

        Item.remove([sAccId,sFolId,value],e.shiftKey,'',this,iNext);
	    break;
	}
};

==> IceWarpServer-10.1.4_RHEL5.tar.gz: html/webmail/client/inc/obj_datagrid2_ext.js <==
_me = obj_datagrid2_ext.prototype;
function obj_datagrid2_ext(){};

//////////// Drag & Drop ////////////////////

_me.__initdrag = function(id,x,y){

	//Check if ID is already in selection, if not make new one
	if (inArray(this.__value,id)<0)
		this._value([id]);

	//prepare data
	var v, data, out = [], f = this._getFolder(),
		sType = dataSet.get('folders',[f.aid,f.fid,'TYPE']),
		sBody = '<table class="tbl_datagrid_'+sType+'">',
		aRights = WMFolders.getAccess(f);

	for(var i in this.__valueData){

		if (!(data = this.__valueData[i]))
			continue;
		/*
		if (!(data = this._aData[this.__value[i]]))
			continue;
		*/
		out.push(typeof data == 'object' && data.arg?data.arg:{id:id});

		//prepare body
		switch(sType){
		case 'R':
			sBody += '<tr><th>'+ (data.data.SUBJECT?data.data.SUBJECT[0]:'') +'</th><td>'+ (data.data.FROM?data.data.FROM:'') +'</td><td>'+ (data.data.DATE?data.data.DATE[0]:'') +'</td></tr>';
			break;
		case 'Q':
		case 'M':
			sBody += '<tr><th>'+ (data.data.SUBJECT?data.data.SUBJECT[0]:'') +'</th><td>'+ (data.data.DATE?data.data.DATE[0]:'') +'</td><td>'+ (data.data.SIZE?data.data.SIZE[0]:'') +'</td></tr>';
			break;
		case 'J':
		case 'E':
			sBody += '<tr><th>'+ (data.data.EVNTITLE?data.data.EVNTITLE[0]:'') +'</th><td>'+ (data.data.EVENT_STARTDATE?data.data.EVENT_STARTDATE[0]:'') +'</td><td>-</td><td>'+ (data.data.EVENT_ENDDATE?data.data.EVENT_ENDDATE[0]:'') +'</td></tr>';
			break;
		case 'N':
			sBody += '<tr><th>'+ (data.data.EVNTITLE?data.data.EVNTITLE[0]:'') +'</th>';
			break;
		case 'T':
			sBody += '<tr><th>'+ (data.data.EVNTITLE?data.data.EVNTITLE[0]:'') +'</th><td>'+ (data.data.TASK_ENDDATE?data.data.TASK_ENDDATE[0]:'') +'</td></tr>';
			break;
		case 'C':
			sBody += '<tr><th>'+ (data.data.ITMCLASSIFYAS?(typeof data.data.ITMCLASSIFYAS == 'object'?data.data.ITMCLASSIFYAS[0]:data.data.ITMCLASSIFYAS):'') +'</th><td>'+ data.data.CONTACT_EMAIL +'</td></tr>';
			break;
		case 'F':
			sBody += '<tr><th>'+ data.data.EVNFILENAME +'</th><td>'+ (data.data.EVNFILESIZE?data.data.EVNFILESIZE[0]:'') +'</td></tr>';
			break;
		}
	}
	sBody += '</table>';

	//create Drag box
	if (out.length>0)
		gui.frm_main.dnd.create_drag(sBody, {type:this.__dragtype,value:out}, x, y, !aRights.remove);
};

//////////// EVENTs ////////////////////

_me._ondblclick = function(e,elm,arg){
	if (!elm){
		if (arg && arg['aid'] && arg['fid']){
			switch(dataSet.get('folders',[arg['aid'],arg['fid'],'TYPE'])){
				case 'C':
				case 'L':
				case 'E':
				case 'T':
				case 'J':
				case 'F':
				case 'N':
					if (WMFolders.getAccess(arg,'write'))
						Item.createInFolder(arg['aid'],arg['fid']);
				break;
				case 'M':
					NewMessage.compose();
					break;

				case 'QL':
					gui._create('gw', 'frm_blackwhite', '', '', arg['aid'], arg['fid']);
			}
		}
		return;
	}

	var sType = dataSet.get('folders',[arg['aid'],arg['fid'],'TYPE']);
	if (sType == 'C' && dataSet.get('items',[arg['aid'],arg['fid'],arg['iid'],'ITMCLASS']) == 'L')
		sType = 'L';

	if (sType == 'M' || sType == 'Q') {
		var others = new gw_others;
		var aDraftFolder = Path.split(others.get('DEFAULT_FOLDERS','storage')['VALUES']['drafts']);

		if (aDraftFolder[0] != arg['aid'] || aDraftFolder[1] != arg['fid'])
			OldMessage.openwindow([arg['aid'], arg['fid'], arg['iid']]);
		else
			OldMessage.edit([arg['aid'], arg['fid'], arg['iid']]);
	}
	else
	if (sType != 'QL' && (sType != 'F' || !Item.downloadFile([arg['aid'], arg['fid'], arg['iid']])))
		Item.open([arg['aid'],arg['fid'],arg['iid']],'','',sType);
};

_me._oncontext = function(e,elm,arg,sLineId,sColumn){
	var bOut = false;

	//Klikly jsme na msto bez poloek?
	if (!arg || !arg['iid']){
		aItems = dataSet.get('items');

		for(var sAccId in aItems)
			for(var sFolId in aItems[sAccId])
			    break;

		var arg = {'aid':sAccId,'fid':sFolId};
		bOut = true;
	}

	var sType = dataSet.get('folders',[arg['aid'],arg['fid'],'TYPE']);

	gui._create("cmenu","obj_context_item",'','',this);

	if (!bOut){
		if (sType == 'C' && dataSet.get('items',[arg['aid'],arg['fid'],arg['iid'],'ITMCLASS']) == 'L')
			sType = 'L';

		var aSelected = this._value();
		var bDisableOpen = false;

		if (inArray(aSelected,arg['iid']) >= 0 && aSelected.length > 1)
			bDisableOpen = true;

		if (inArray(aSelected,arg['iid']) < 0)
			aSelected = [arg['iid']];

		arg.data = dataSet.get('items',[arg['aid'],arg['fid'],arg['iid']]);

		gui.cmenu._fillMenu(sType,arg,aSelected,bDisableOpen,false,sColumn);
	}
 	else
		gui.cmenu._fillGeneralMenu(sType,arg);

	gui.cmenu._place(e.clientX,e.clientY);
};

_me._onclick = function(e,elm,arg,line,column,aClickType)
{
	if (inArray(aClickType,'SHIFT') > -1 || inArray(aClickType,'CTRL') > -1)
		return;

	var sType = dataSet.get('folders',[arg['aid'],arg['fid'],'TYPE']);
	if (sType == 'C' && dataSet.get('items',[arg['aid'],arg['fid'],arg['iid'],'ITMCLASS']) == 'L')
		sType = 'L';
			
	switch (sType) {
		case 'R':
			dataSet.add('active_mails',[arg['aid'],arg['fid']],arg['iid']);
			OldMessage.open([arg['aid'], arg['fid'], arg['iid']]);
			break;

		case 'T':
			if (column == 'EVNSTATUS') {
				var sCurrentStatus = dataSet.get('items',[arg['aid'],arg['fid'],arg['iid']])['EVNSTATUS'];

				var sStatus = (sCurrentStatus != 'M') ? 'M' : 'I';

				// TODO rollback on error
				dataSet.add('items', [arg['aid'], arg['fid'], arg['iid'], 'EVNSTATUS'], sStatus);
				WMItems.add([arg['aid'], arg['fid'], arg['iid']], {'values': {'EVNSTATUS': sStatus}}, 'items');
				break;
			}

		case 'C':
		case 'L':
		case 'E':
		case 'J':
		case 'N':
		case 'F':
			//Execute Edit dialog on Enter
			if (e.type == 'keydown' && e.keyCode == 13)
				gui._create('gw',Mapping.getFormNameByGWType(sType),'','',arg['aid'],arg['fid'],arg['iid']);
			break;
			
		case 'Q':
		case 'M':
            var aRights = WMFolders.getAccess(arg);
			if (column == 'COLOR' && aRights.modify) {
				var id = [arg['aid'],arg['fid'],arg['iid']];
				var sColor = OldMessage.getColor(id);

				if (sColor && (sColor == Item.COLORS.COMPLETE || sColor == Item.COLORS.CLEAR)) {
					storage.library('gw_others');
					var sDefaultColor = GWOthers.getItem('MAIL_SETTINGS_GENERAL','default_flag');

					OldMessage.setColor(id, sDefaultColor);
				}
				else
					OldMessage.setColor(id, Item.COLORS.COMPLETE);
			}
			else {
				if (column === null && e.ctrlKey)
	                OldMessage.openwindow([arg['aid'], arg['fid'], arg['iid']]);
				else{
       				dataSet.add('active_mails',[arg['aid'],arg['fid']],arg['iid']);
					OldMessage.open([arg['aid'], arg['fid'], arg['iid']]);
				}
			}
			break;
	}
};

_me._onkeydown = function(e){
	// nacte vybrane radky
	var value = this._value();
	if (Is.Empty(value)) return;

	//ziska sFolId a sAccId
	var aFolder = this._getFolder(),
		sAccId = aFolder.aid,
		sFolId = aFolder.fid,
		sType = dataSet.get('folders',[sAccId,sFolId,'TYPE']);

	//numbers as Flags
	if ((e.keyCode>95 && e.keyCode<106) || (e.keyCode==107 || e.keyCode==109)){
		var color;
		if (e.keyCode==107)
			color = 'COMPLETE';
		else
		if (e.keyCode==109)
			color = 'CLEAR';
		else{
			if (sType == 'M' || sType == 'R')
				var colors = ['RED','BLUE','GREEN','ORANGE','PURPLE','YELLOW'];
			else
			if (sType == 'N')
				var colors = ['BLUE','GREEN','RED','','GREY','YELLOW'];
			else
				var colors = ['RED','BLUE','GREEN','GREY','ORANGE','CYAN','BROWN','PURPLE','LIGHT_BLUE','YELLOW'];

			if(!(color = colors[e.keyCode-96])) return;
		}

		for(var i in value)
			if (sType == 'M' || sType == 'R')
				OldMessage.setColor([sAccId,sFolId,value[i]], Item.COLORS[color]);
			else
			if (WMFolders.getAccess({aid:sAccId,fid:sFolId},'modify'))
				Item.setColor([sAccId,sFolId,value[i]], Item.COLORS[color]);
	}
	else
	switch(e.keyCode){
	case 82:
		//r - Reply or Reply All
	    if (sType=='M')
			OldMessage.reply([sAccId,sFolId,value[0]],e.shiftKey);
		break;
	case 70:
		//f - Forward or FW as attachment
	    if (sType=='M')
			OldMessage.forward([sAccId,sFolId,value[0]],e.shiftKey);
		break;
	case 78: //n - New
	    if (sType=='M')
	        NewMessage.compose();
	    break;
	case 67: //c - Copy
		Item.copy([sAccId,sFolId,value]);
	    break;
	case 77: //m - Move
 		if (sType!='M' && !WMFolders.getAccess({aid:sAccId,fid:sFolId},'remove')) break;
		Item.move([sAccId,sFolId,value]);
	    break;
	case 69: //e - Read
	    if (sType=='M' || sType=='R')
			for(var i in value)
				OldMessage.markAsRead([sAccId,sFolId,value]);
		break;
	case 85: //u - Unread
	    if (sType=='M' || sType=='R')
			for(var i in value)
				OldMessage.markAsUnread([sAccId,sFolId,value]);
	    break;
	case 46: //delete
        this.__deleteItems(aFolder,value,e.shiftKey);
	}
};

_me.__deleteItems = function(aFolder,value,shiftKey,oRepeating){

		var sType = dataSet.get('folders',[aFolder.aid,aFolder.fid,'TYPE']);

		if (sType!='Q' && sType!='QL' && !WMFolders.getAccess(aFolder,'remove')) return;

		var pos = 0, v = clone(value), act = v.pop(), tmp = [], b;

		for(var i in this._aData){
			b = false;
			for(j in v){
				if (v[j] == i){
				    b = true
				    break;
				}
			}

			if (!b){
				if (act == i)
				    pos = tmp.length;

				tmp.push(i);
			}
		}

		tmp.splice(pos,1);

		var iNext;
		if (typeof tmp[pos] == 'undefined'){
			if (pos>0)
                iNext = tmp[--pos];
		    else
		    if (typeof tmp[pos+1] == 'undefined')
                iNext = tmp[pos];
		    else
                iNext = tmp[++pos];
		}
		else
            iNext = tmp[pos];

        Item.remove([aFolder.aid,aFolder.fid,value],shiftKey,oRepeating,this,iNext);
};
